# Interface Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines#description)
  * [Interface Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines#interface-fact-sheet-subtypes)
  * [Guidelines and Best Practices](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines#guidelines-and-best-practices)
  * [Understanding Interface Providers and Consumers](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines#understanding-interface-providers-and-consumers)
  * [Capturing the Direction of the Data Flow](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines#capturing-the-direction-of-the-data-flow)
  * [How to Model Interfaces](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines#how-to-model-interfaces)
  * [How to Model Middleware](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines#how-to-model-middleware)


View all
Learn how to model interfaces. This includes best practices and applicable use cases, and common antipatterns.
**Note**
These modeling guidelines are for the meta model v4. For meta model v3 guidelines, see [Modeling: Interfaces](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "The Interface Fact Sheet addresses the Integration Architecture Management use case and can be used in combination with the Interface Circle Map and Data Flow Report.").
